@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-import alabaster
 from sprockets.mixins import metrics
 
 project = 'sprockets.mixins.metrics'
@@ -7,23 +5,15 @@ copyright = 'AWeber Communications, Inc.'
 version = metrics.__version__
 release = '.'.join(str(v) for v in metrics.version_info[0:2])
 
-needs_sphinx = '1.0'
 extensions = [
     'sphinx.ext.autodoc',
     'sphinx.ext.intersphinx',
     'sphinx.ext.viewcode',
 ]
 
-templates_path = []
-source_suffix = '.rst'
-source_encoding = 'utf-8-sig'
 master_doc = 'index'
-exclude_patterns = []
-pygments_style = 'sphinx'
 html_style = 'custom.css'
 html_static_path = ['_static']
-html_theme = 'alabaster'
-html_theme_path = [alabaster.get_path()]
 html_sidebars = {
     '**': ['about.html', 'navigation.html'],
 }
