@@ -1,7 +1,8 @@
+import asyncio
 import signal
 
 from sprockets.mixins.metrics import statsd
-from tornado import concurrent, gen, ioloop, web
+from tornado import ioloop, web
 
 
 class SimpleHandler(statsd.StatsdMixin, web.RequestHandler):
@@ -14,19 +15,8 @@ class SimpleHandler(statsd.StatsdMixin, web.RequestHandler):
 
     """
 
-    @gen.coroutine
-    def prepare(self):
-        maybe_future = super(SimpleHandler, self).prepare()
-        if concurrent.is_future(maybe_future):
-            yield maybe_future
-
-        if 'Correlation-ID' in self.request.headers:
-            self.set_metric_tag('correlation_id',
-                                self.request.headers['Correlation-ID'])
-
-    @gen.coroutine
-    def get(self):
-        yield gen.sleep(0.25)
+    async def get(self):
+        await asyncio.sleep(0.25)
         self.set_status(204)
         self.finish()
 
@@ -52,14 +42,10 @@ def make_application():
         webapps.SimpleHandler.GET.204:255.24497032165527|ms
 
     """
-    settings = {
-        statsd.SETTINGS_KEY: {
-            'namespace': 'webapps',
-            'host': '127.0.0.1',
-            'port': 8125,
-        }
-    }
-    return web.Application([web.url('/', SimpleHandler)], **settings)
+    settings = {}
+    application = web.Application([web.url('/', SimpleHandler)], **settings)
+    statsd.install(application, **{'namespace': 'testing'})
+    return application
 
 
 if __name__ == '__main__':
